==> sigaddons-7.0.21.12.14.tar.gz: sigaddons-7.0.21.12.14/sigaddons/coletor_wms/__openerp__.py <==
# -*- coding: utf-8 -*-
################################################################################
#
# Copyright (C) 2009-2015 All Rights Reserved. Luiz Fernando Maciel Franca
#              www.siginformatica.com.br <luiz@siginformatica.com.br>
#                                -------
#
# Copyleft (CC) 2015, Creative Commons
# Autor - Pierre Geraldo Moura Barbosa <barbosa.pierre[at]gmail.com>
#
# Atribuicao-Nao Comercial-Compartilhada Igual 3 Nao Adaptada (CC BY-NC-SA 3.0)
# http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
#
################################################################################

{
    'name': 'Modulo coletor do WMS.',
    'description': """
Modulo coletor WMS
==================

Modulo de manipulacao de dados de **entrada** do WMS a partir de um coletor de dados.

Permite:
--------

* Entrada/manutencao de dados diretamente a partir de um coletor de dados
* Visualizacao de dados logisticos dos produtos
* Recebimento de mercadorias
* Enderecamento de produtos no armazem (C.D.)
* Tranferencia/movimentacao de mercadorias
* Conferencia (Box)
* Inventario

""",
    'category': 'Estoque',
    'summary': 'Coletor de dados WMS',
    'version': '7.0.21.12.14',
    'author': 'Sig Informatica Ltda',
    'website': 'http://www.siginformatica.com.br',
    'depends': ['coletor', 'wms'],
    'data': [
        'data/modulo.xml',
        'inherit/coletor/coletor_view.xml',
    ],
    'license': 'Other proprietary',
    'installable': True,
    'application': True,
    'active': False,
}

==> sigaddons-7.0.2310.2.tar.gz: sigaddons-7.0.2310.2/sigaddons/coletor_wms/__openerp__.py <==
# -*- coding: utf-8 -*-
################################################################################
#
# Copyright (C) 2009-2015 All Rights Reserved. Luiz Fernando Maciel Franca
#              www.siginformatica.com.br <luiz@siginformatica.com.br>
#                                -------
#
# Copyleft (CC) 2015, Creative Commons
# Autor - Pierre Geraldo Moura Barbosa <barbosa.pierre[at]gmail.com>
#
# Atribuicao-Nao Comercial-Compartilhada Igual 3 Nao Adaptada (CC BY-NC-SA 3.0)
# http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
#
################################################################################

{
    'name': 'Modulo coletor do WMS.',
    'description': """
Modulo coletor WMS
==================

Modulo de manipulacao de dados de **entrada** do WMS a partir de um coletor de dados.

Permite:
--------

* Entrada/manutencao de dados diretamente a partir de um coletor de dados
* Visualizacao de dados logisticos dos produtos
* Recebimento de mercadorias
* Enderecamento de produtos no armazem (C.D.)
* Tranferencia/movimentacao de mercadorias
* Conferencia (Box)
* Inventario

""",
    'category': 'Estoque',
    'summary': 'Coletor de dados WMS',
    'version': '7.0.2310.2',
    'author': 'Sig Informatica Ltda',
    'website': 'http://www.siginformatica.com.br',
    'depends': ['coletor', 'wms'],
    'data': [
        'data/modulo.xml',
        'inherit/coletor/coletor_view.xml',
    ],
    'license': 'Other proprietary',
    'installable': True,
    'application': True,
    'active': False,
}
